==> ugene_1.19.0%2Bdfsg.orig.tar.xz: ugene-1.19.0/src/plugins/GUITestBase/src/tests/common_scenarios/workflow_designer/GTTestsWorkflowDesigner.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2015 UniPro <ugene@unipro.ru>
 * http://ugene.unipro.ru
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
k
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef GTTESTS_WORKFLOW_DESIGNER_H_
#define GTTESTS_WORKFLOW_DESIGNER_H_

#include <U2Test/GUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_workflow_designer {
#undef GUI_TEST_PREFIX
#define GUI_TEST_PREFIX "GUITest_common_scenarios_workflow_designer_"

GUI_TEST_CLASS_DECLARATION(test_0001)
GUI_TEST_CLASS_DECLARATION(test_0002)
GUI_TEST_CLASS_DECLARATION(test_0002_1)
GUI_TEST_CLASS_DECLARATION(test_0003)
GUI_TEST_CLASS_DECLARATION(test_0005)
GUI_TEST_CLASS_DECLARATION(test_0006)
GUI_TEST_CLASS_DECLARATION(test_0006_1)
GUI_TEST_CLASS_DECLARATION(test_0007)
GUI_TEST_CLASS_DECLARATION(test_0009)
GUI_TEST_CLASS_DECLARATION(test_0010)
GUI_TEST_CLASS_DECLARATION(test_0013)
GUI_TEST_CLASS_DECLARATION(test_0015)
GUI_TEST_CLASS_DECLARATION(test_0015_1)
GUI_TEST_CLASS_DECLARATION(test_0016)
GUI_TEST_CLASS_DECLARATION(test_0017)

GUI_TEST_CLASS_DECLARATION(test_0058)
GUI_TEST_CLASS_DECLARATION(test_0059)
GUI_TEST_CLASS_DECLARATION(test_0060)

#undef GUI_TEST_PREFIX
} // namespace U2

} //namespace

#endif // GTTESTS_WORKFLOW_DESIGNER_H_

==> ugene_1.20.0%2Bdfsg.orig.tar.xz: ugene-1.20.0/src/plugins/GUITestBase/src/tests/common_scenarios/workflow_designer/GTTestsWorkflowDesigner.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2015 UniPro <ugene@unipro.ru>
 * http://ugene.unipro.ru
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
k
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef GTTESTS_WORKFLOW_DESIGNER_H_
#define GTTESTS_WORKFLOW_DESIGNER_H_

#include <U2Test/GUITestBase.h>

namespace U2 {

namespace GUITest_common_scenarios_workflow_designer {
#undef GUI_TEST_SUITE
#define GUI_TEST_SUITE "GUITest_common_scenarios_workflow_designer"

GUI_TEST_CLASS_DECLARATION(test_0001)
GUI_TEST_CLASS_DECLARATION(test_0002)
GUI_TEST_CLASS_DECLARATION(test_0002_1)
GUI_TEST_CLASS_DECLARATION(test_0003)
GUI_TEST_CLASS_DECLARATION(test_0005)
GUI_TEST_CLASS_DECLARATION(test_0006)
GUI_TEST_CLASS_DECLARATION(test_0006_1)
GUI_TEST_CLASS_DECLARATION(test_0007)
GUI_TEST_CLASS_DECLARATION(test_0009)
GUI_TEST_CLASS_DECLARATION(test_0010)
GUI_TEST_CLASS_DECLARATION(test_0013)
GUI_TEST_CLASS_DECLARATION(test_0015)
GUI_TEST_CLASS_DECLARATION(test_0015_1)
GUI_TEST_CLASS_DECLARATION(test_0016)
GUI_TEST_CLASS_DECLARATION(test_0017)

GUI_TEST_CLASS_DECLARATION(test_0058)
GUI_TEST_CLASS_DECLARATION(test_0059)
GUI_TEST_CLASS_DECLARATION(test_0060)

#undef GUI_TEST_SUITE
} // namespace U2

} //namespace

#endif // GTTESTS_WORKFLOW_DESIGNER_H_
